@@ -41,4 +41,7 @@ class Peptide(object):
         if average:
             pass
         else:
-            return sum([config.RESIDUE_MASSES[i][0] for i in self.sequence.upper()])
\ No newline at end of file
+            return sum([config.RESIDUE_MASSES[i][0] for i in self.sequence.upper()])
+
+    def getMSMass(self, charge=0):
+        return (self.getMass()+(charge-1)*config.HYDROGEN)/float(charge)
\ No newline at end of file
