@@ -7,21 +7,21 @@ import pythomics.proteomics.config as protein_config
 
 
 class GenericIterator(object):
-    gz = False
+    gzip = False
     CHUNK_SIZE = 2**16
     UNCONSUMED = ''
     contents = []
 
-    def __init__(self, filename, delimiter='\n', **kwrds):
+    def __init__(self, filename, delimiter='\n', *args, **kwargs):
         self.delimiter = delimiter
         if isinstance(filename, basestring) and filename.endswith('.gz'):
-            self.gz = True
+            self.gzip = True
             self.filename = gzip.GzipFile(filename)
         elif isinstance(filename, basestring):
             self.filename = open(filename)
         elif isinstance(filename, (file,)):
             if filename.name.endswith('.gz'):
-                self.gz = True
+                self.gzip = True
                 self.filename = gzip.GzipFile(filename.name)
             else:
                 self.filename = filename
@@ -32,7 +32,7 @@ class GenericIterator(object):
         return self
 
     def next(self):
-        if self.gz:
+        if self.gzip:
             if self.contents:
                 return self.contents.popleft()
             new_contents = self.filename.read(self.CHUNK_SIZE)
@@ -84,7 +84,7 @@ class CustomParser(argparse.ArgumentParser):
         self.add_argument(*header, help="The number of headers lines (default: 1).", type=int, default=1)
 
     def add_fasta(self, help="The fasta file to operate on."):
-        self.add_argument('-f', '--fasta', nargs='?', help=help, type=argparse.FileType('r'))
+        self.add_argument('-f', '--fasta', nargs='?', help=help, type=argparse.FileType('r'), required=True)
 
     def add_read_pair(self):
         self.add_argument('--left', help="The left (5') read pairs", nargs='?', type=argparse.FileType('r'))
@@ -100,7 +100,7 @@ class CustomParser(argparse.ArgumentParser):
         self.add_argument('--no-snps', help="Don't use SNPs (default to true).", action='store_false')
         self.add_argument('--dels', help="Use Deletions.", action='store_true')
         self.add_argument('--ins', help="Use Insertions.", action='store_true')
-        self.add_argument('--individual', help="The Individual to use.", type=int, default=1)
+        self.add_argument('--individual', help="The Individual to use.", type=str, default=None)
         self.add_argument('--append-chromosome', help="Should 'chr' be appended to the chromosome column?.", action='store_true')
 
     def add_bam(self, help="The SAM/BAM file to use"):
@@ -129,7 +129,22 @@ class CustomParser(argparse.ArgumentParser):
     def add_ms_files(self, help='The corresponding raw mass spectrometry file (ie .raw, .mzml).'):
         self.add_argument('--raw', nargs='?', help=help, type=str)
 
-    def add_processed_ms(self, help='The corresponding processed mass spectrometry files (ie .msf, .dat).'):
-        self.add_argument('--processed', nargs='?', help=help, type=str)
+    def add_processed_ms(self, group=None, help='The corresponding processed mass spectrometry files (ie .msf, .dat).', required=True):
+        parser = self if group is None else group
+        parser.add_argument('--processed', help=help, type=argparse.FileType('r'), required=required)
+
+    def add_column_function(self, argument,
+                            help="The column to apply a function to (if you want to combine fields, sum fields, etc.).",
+                            col_argument=None, group=None, col_help="The function to apply.", col_default='concat', parent=True):
+        adder = self
+        if group:
+            adder = group
+        from ..utils import ColumnFunctions
+        if col_argument is None:
+            col_argument = '{}-func'.format(argument)
+        if parent:
+            adder.add_argument(argument, help=help, type=str)
+        adder.add_argument(col_argument, help='{0} Options: {1}'.format(col_help, ', '.join(ColumnFunctions.METHODS)),
+                           type=str, choices=ColumnFunctions.METHODS, default=col_default)
 
 
